@@ -26,11 +26,32 @@ py['blog_language'] = "en"
 # Encoding for output. Default is iso-8859-1.
 py['blog_encoding'] = "iso-8859-1"
 
+# These are the rights you give to others in regards to the content
+# on your blog.  Generally, this is the copyright information.
+# This is used in the Atom feeds.  Leaving this blank or not filling
+# it in correctly could result in a feed that doesn't validate.
+py["blog_rights"] = "Copyright 2005 Joe Bobb"
+
 # Where are this blog's entries kept?
 py['datadir'] = "/path/to/blog"
 
-# Where should PyBlosxom log files be kept?
-py['logdir'] = "/path/to/logdir"
+# Where should the application log to?
+# If set to "NONE" log messages are silently ignored.
+# Falls back to sys.stderr if the file can't be opened for writing.
+# py['log_file'] = "/path/to/pyblosxom.log"
+
+# At what level should we log to log_file?
+# One of: critical, error, warning, info, debug
+# For production 'warning' or 'error' is recommended.
+# py['log_level'] = "warning"
+
+# Let's you specify which channels should be logged.
+# If specified, only messages from the listed channels are logged.
+# Each plugin logs to it's own channel, therefor channelname == pluginname.
+# Application level messages are logged to a channel named 'root'.
+# If you use log_filter and ommit the 'root' channel here, app level messages 
+# are not logged! log_filter is mainly interesting to debug a specific plugin.
+# py['log_filter'] = ['root', 'plugin1', 'plugin2']
 
 # List of strings with directories that should be ignored (e.g. "CVS")
 # ex: py['ignore_directories'] = ["CVS", "temp"]
@@ -41,7 +62,9 @@ py['ignore_directories'] = []
 # 0 = infinite depth (aka grab everything), 1 = datadir only, n = n levels down
 py['depth'] = 0
 
-# How many entries should I show on the home page?
+# How many entries should I show on the home page and category pages?
+# This doesn't affect date-based archive pages.  If you put 0 here, 
+# then I will show all pages.
 py['num_entries'] = 40
 
 # What should the default flavour you want used be?
